@@ -27,8 +27,8 @@
 # SOFTWARE.
 
 
-import io
 import logging
+import os
 import sys
 from typing import List, Optional, Tuple
 
@@ -37,6 +37,7 @@ from PyQt6.QtCore import QByteArray, QEvent, QObject, QRectF, QSize, Qt, QTimer
 from PyQt6.QtGui import (
     QCloseEvent,
     QEnterEvent,
+    QIcon,
     QImage,
     QKeyEvent,
     QMouseEvent,
@@ -45,14 +46,31 @@ from PyQt6.QtGui import (
     QPixmap,
 )
 from PyQt6.QtSvg import QSvgRenderer
-from PyQt6.QtWidgets import QApplication, QDialog, QSizePolicy, QWidget
+from PyQt6.QtWidgets import (
+    QApplication,
+    QDialog,
+    QPushButton,
+    QSizePolicy,
+    QVBoxLayout,
+    QWidget,
+)
 
 from bitcoin_qr_tools.data import Data
 from bitcoin_qr_tools.qr_generator import QRGenerator
+from bitcoin_qr_tools.unified_encoder import QrExportTypes, UnifiedEncoder
 
 logger = logging.getLogger(__name__)
 
 
+def resource_path(*parts: str):
+    pkg_dir = os.path.split(os.path.realpath(__file__))[0]
+    return os.path.join(pkg_dir, *parts)
+
+
+def icon_path(icon_basename: str):
+    return resource_path("gui", "icons", icon_basename)
+
+
 def pil_image_to_qimage(im: Image.Image):
     im = im.convert("RGBA")
     data = im.tobytes("raw", "RGBA")
@@ -115,7 +133,9 @@ class ImageWidget(QWidget):
 
 
 class EnlargableImageWidget(ImageWidget):
-    def __init__(self, pil_image: Image = None, parent=None, size_hint: Tuple[int, int] = None):
+    def __init__(
+        self, pil_image: Image.Image | None = None, parent=None, size_hint: Tuple[int, int] | None = None
+    ):
         super().__init__(pil_image, parent, size_hint=size_hint)
         self.enlarged_image: Optional[EnlargedImage] = None
         self.setCursor(Qt.CursorShape.PointingHandCursor)
@@ -140,7 +160,7 @@ class EnlargableImageWidget(ImageWidget):
 
 
 class EnlargedImage(ImageWidget):
-    def __init__(self, pil_image: Image, parent=None, screen_fraction=0.7):
+    def __init__(self, pil_image: Image.Image, parent=None, screen_fraction=0.7):
         super().__init__(pil_image, parent)
         self.setWindowTitle("Enlarged Image")
         self.installEventFilter(self)  # Install the event filter for this widget
@@ -180,6 +200,32 @@ class EnlargedImage(ImageWidget):
             self.close()
 
 
+class EnlargableImageWidgetWithButton(QWidget):
+    def __init__(
+        self,
+        pil_image: Image.Image | None = None,
+        parent: QWidget | None = None,
+        size_hint: Tuple[int, int] | None = None,
+    ):
+        super().__init__(parent)
+
+        layout = QVBoxLayout(self)
+        self.enlargable_widget = EnlargableImageWidget(pil_image=pil_image, parent=self, size_hint=size_hint)
+
+        layout.addWidget(self.enlargable_widget)
+
+        self.button_enlarge_qr = QPushButton()
+        self.button_enlarge_qr.setIcon(QIcon(icon_path("zoom.png")))
+        # self.button_enlarge_qr.setIconSize(QSize(30, 30))  # 24x24 pixels
+        self.button_enlarge_qr.clicked.connect(self.enlargable_widget.enlarge_image)
+        self.button_enlarge_qr.setText(self.tr("Enlarge"))
+        self.button_enlarge_qr.setMaximumWidth(200)
+        layout.addWidget(self.button_enlarge_qr, alignment=Qt.AlignmentFlag.AlignHCenter)
+
+    def load_from_file(self, filepath: str):
+        self.enlargable_widget.load_from_file(filepath=filepath)
+
+
 class QRCodeWidget(EnlargableImageWidget):
     def __init__(self, parent=None, clickable=True):
         super().__init__(parent=parent)
@@ -300,7 +346,7 @@ class QRCodeWidgetSVG(QWidget):
             self.enlarge_image()
         super().mousePressEvent(event)
 
-    def save_file(self, base_filename: str, format="PNG", antialias=False):
+    def save_file(self, base_filename: str, image_format="PNG", antialias=False):
         """Save all QR codes to files. If format is 'GIF', combines them into
         an animated GIF.
 
@@ -310,14 +356,14 @@ class QRCodeWidgetSVG(QWidget):
         :param antialias: Boolean to indicate if anti-aliasing should be
             used.
         """
-        if format.upper() == "GIF":
+        if image_format.upper() == "GIF":
             images = []
             for renderer in self.svg_renderers:
                 if not renderer.isValid():
                     continue
-                images.append(self.renderer_to_pil(renderer, antialias))
+                images.append(self.renderer_to_pil(renderer, antialias, image_format))
             images[0].save(
-                f"{base_filename}.gif",
+                f"{base_filename}.{image_format.lower()}",
                 save_all=True,
                 append_images=images[1:],
                 loop=0,
@@ -328,9 +374,9 @@ class QRCodeWidgetSVG(QWidget):
                 if not renderer.isValid():
                     continue
                 image = self.renderer_to_pil(renderer, antialias)
-                image.save(f"{base_filename}_{i}.{format.lower()}")
+                image.save(f"{base_filename}_{i}.{image_format.lower()}")
 
-    def renderer_to_pil(self, renderer: QSvgRenderer, antialias: bool):
+    def renderer_to_pil(self, renderer: QSvgRenderer, antialias: bool, image_format="PNG"):
         """Convert a QR code renderer to a PIL Image.
 
         :param renderer: The QR code renderer.
@@ -338,25 +384,41 @@ class QRCodeWidgetSVG(QWidget):
             used.
         :return: PIL Image object.
         """
-        size = self.size()
-        pixmap = QPixmap(size)
+        # setting the length that it can handle the largets qr codes:
+        # Version 40: 177x177 modules
+        length = 177 * 2
+
+        pixmap = QPixmap(length, length)
         pixmap.fill(Qt.GlobalColor.white)
         painter = QPainter(pixmap)
 
         if antialias:
             painter.setRenderHint(QPainter.RenderHint.Antialiasing)
 
-        renderer.render(painter, QRectF(0, 0, size.width(), size.height()))
+        renderer.render(painter, QRectF(0, 0, length, length))
         painter.end()
 
         # Convert QPixmap to QImage
         qimage = pixmap.toImage()
 
-        # Convert QImage to PIL Image
-        buffer = io.BytesIO()
-        qimage.save(buffer, "PNG")  # type: ignore
-        buffer.seek(0)
-        return Image.open(buffer)
+        return self.qimage_to_pil(qimage=qimage)
+
+    @staticmethod
+    def qimage_to_pil(qimage: QImage) -> Image.Image:
+        """Convert QImage to PIL Image."""
+        qimage = qimage.convertToFormat(QImage.Format.Format_RGB32)
+
+        width = qimage.width()
+        height = qimage.height()
+
+        # Get the data from the QImage
+        # 4 bytes per pixel
+        buffer = qimage.bits().asstring(width * height * 4)  # type: ignore
+
+        # Create a PIL Image from the buffer
+        pil_image = Image.frombytes("RGBA", (width, height), buffer, "raw", "BGRA")
+
+        return pil_image
 
     def as_pil_images(self):
         """Convert all the QR codes to PIL Images.
@@ -422,13 +484,21 @@ if __name__ == "__main__":
     import bdkpython as bdk
 
     app = QApplication(sys.argv)
-    widget = QRCodeWidgetSVG()
 
+    main = QWidget()
+    layout = QVBoxLayout(main)
+
+    svg_widget = QRCodeWidgetSVG()
     psbt = "cHNidP8BAHEBAAAAAXgQzjk+DTWQTPUtRMbYiheC0jfbipvw+jQ5lidmyABjAAAAAAD9////AgDh9QUAAAAAFgAUbBuOQOlcnz8vpruh2Kb3CFr4vlhkEQ2PAAAAABYAFN1n2hvBWYzshD42xwQzy9XYoji3BAEAAAABAKoCAAAAAAEBAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAD/////BQKYAAEB/////wIA+QKVAAAAABYAFLlHwN6VXNLM381bMxmNJlaDTQzVAAAAAAAAAAAmaiSqIant4vYcP3HR3v0/qZnfo2lTdVxpBol5mWK0i+vYNpdOjPkBIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAEBHwD5ApUAAAAAFgAUuUfA3pVc0szfzVszGY0mVoNNDNUiBgISCnRxeOxzC0MgK01AmiIRLrgS1AyIqKeBkdwL+nt/6RikLG3TVAAAgAEAAIAAAACAAAAAAAAAAAAAACICAlQcwExiTUk9f7olLkwPlQpiregRHc9jXXFJBlMoucgNGKQsbdNUAACAAQAAgAAAAIAAAAAAAQAAAAA="
     data: Data = Data.from_str(psbt, network=bdk.Network.REGTEST)
-    fragments = data.generate_fragments_for_qr(qr_type="bbqr")
+    fragments = UnifiedEncoder.generate_fragments_for_qr(data=data, qr_export_type=QrExportTypes.bbqr)
+    svg_widget.set_data_list(fragments)
 
-    widget.set_data_list(fragments)
-    widget.show()
+    enlarable_widget2 = EnlargableImageWidgetWithButton()
+    enlarable_widget2.load_from_file("docs/bad-light.png")
+
+    layout.addWidget(svg_widget)
+    layout.addWidget(enlarable_widget2)
+    main.show()
 
     sys.exit(app.exec())
